==> chromium_79.0.3945.130.orig.tar.xz: chromium-79.0.3945.130/chrome/browser/sharing/sharing_constants.h <==
// Copyright 2019 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef CHROME_BROWSER_SHARING_SHARING_CONSTANTS_H_
#define CHROME_BROWSER_SHARING_SHARING_CONSTANTS_H_

#include "base/time/time.h"
#include "net/base/backoff_entry.h"

// InstanceID scope for Google Cloud Messaging to get GCM enabled token.
extern const char kFCMScope[];

// Sender ID linked to GCM messages for Sharing.
extern const char kSharingFCMAppID[];

// Amount of time before an ack message is expired.
extern const base::TimeDelta kAckTimeToLive;

// Amount of offline time before decice is consider expired.
extern const base::TimeDelta kDeviceExpiration;

// Amount of time before FCM registration should happen again.
extern const base::TimeDelta kRegistrationExpiration;

// Amount of time before a message is considered timeout if no ack is received.
extern const base::TimeDelta kSendMessageTimeout;

// Backoff policy for registration retry.
extern const net::BackoffEntry::Policy kRetryBackoffPolicy;

// Time limit for message expiration.
extern const base::TimeDelta kSharingMessageTTL;

// Maximum number of devices to be shown in dialog and context menu.
extern const int kMaxDevicesShown;

// Command id for first device shown in submenu.
extern const int kSubMenuFirstDeviceCommandId;

// Command id for last device shown in submenu.
extern const int kSubMenuLastDeviceCommandId;

// The feature name prefix used in metrics name.
enum class SharingFeatureName {
  kUnknown,
  kClickToCall,
  kSharedClipboard,
  kMaxValue = kSharedClipboard,
};

#endif  // CHROME_BROWSER_SHARING_SHARING_CONSTANTS_H_

==> chromium_89.0.4389.114.orig.tar.xz: chromium-89.0.4389.114/chrome/browser/sharing/sharing_constants.h <==
// Copyright 2019 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef CHROME_BROWSER_SHARING_SHARING_CONSTANTS_H_
#define CHROME_BROWSER_SHARING_SHARING_CONSTANTS_H_

#include "base/time/time.h"
#include "net/base/backoff_entry.h"

// App ID linked to FCM messages for Sharing.
extern const char kSharingFCMAppID[];

// Sender ID for Sharing.
extern const char kSharingSenderID[];

// Amount of time before FCM registration should happen again.
extern const base::TimeDelta kRegistrationExpiration;

// Time until we treat a WebRTC connection as timed out and force close it.
extern const base::TimeDelta kSharingWebRtcTimeout;

// Backoff policy for registration retry.
extern const net::BackoffEntry::Policy kRetryBackoffPolicy;

// Maximum number of devices to be shown in dialog and context menu.
extern const int kMaxDevicesShown;

// Command id for first device shown in submenu.
extern const int kSubMenuFirstDeviceCommandId;

// Command id for last device shown in submenu.
extern const int kSubMenuLastDeviceCommandId;

// The feature name prefix used in metrics name.
enum class SharingFeatureName {
  kUnknown,
  kClickToCall,
  kSharedClipboard,
  kMaxValue = kSharedClipboard,
};

// The device platform that the user is sharing from/with.
enum class SharingDevicePlatform {
  kUnknown,
  kAndroid,
  kChromeOS,
  kIOS,
  kLinux,
  kMac,
  kWindows,
  kServer,
};

enum class SharingChannelType {
  kUnknown,
  kFcmVapid,
  kFcmSenderId,
  kServer,
  kWebRtc
};

#endif  // CHROME_BROWSER_SHARING_SHARING_CONSTANTS_H_
